@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import plotly.graph_objects as go
 from plotly.offline import plot
 import numpy as np
@@ -13,10 +12,19 @@ def randomRgbaColor():
    b =random.randrange(0, 255)
    return "rgb"+ "(" + str(r) + "," + str(g) + ","+ str(b) + ")"
 
+import plotly.graph_objects as go
+import numpy as np
+import math
+from sympy import Matrix
+
 
 def plotvectors2D(*args):
-    '''Función elaborada con el módulo Plotly y Numpy para representar multiples vectores fijos y libres en el plano  
-    ademas de vectores equipolentes que inicien en un punto dado, acepta como argumento vectores de la librería SymPy.'''
+    
+    '''Función elaborada en el módulo Plotly y NumPy para visualizar multiples vectores en el plano cartesiano, que pueden tener 
+    un punto inicial y un punto final dado, estar anclados en el origen del plano, o vectores equipolentes a otro que inicie en 
+    un punto dado (traslación de vectores), y vectores en forma polar anclados en el origen o con un punto inicial dado, 
+    acepta como argumentos vectores unidimensionales o bidimensionales definidos como matriz columna en la librería SymPy'''
+    
     fig = go.Figure()
     x = [0]
     y = [0]
@@ -24,6 +32,7 @@ def plotvectors2D(*args):
 
         nombre = "vector "+ str(args.index(V)+1)
 
+        # plotvector2D([x])
         if type(V)== list and len(V) == 1:
 
             color = randomRgbaColor()
@@ -47,9 +56,11 @@ def plotvectors2D(*args):
             arrowcolor = color)
         
         else:
-            
+
+             
             if (type(V[0]) == int or type(V[0]) == float):
 
+                # plotvector2D([x1,y1])
                 if  (type(V[1]) == int or type(V[1]) == float):
 
                     color = randomRgbaColor()
@@ -75,6 +86,7 @@ def plotvectors2D(*args):
 
                 else:
 
+                    # plotvector2D([a,"b"])
                     r = V[0]
                     theta_str = V[1]
                     theta = math.radians(float(theta_str[:]))
@@ -104,9 +116,46 @@ def plotvectors2D(*args):
                  
                 
             if  type(V[0]) == tuple:
-                
+
+                # plotvector2D([(x0,y0),a,"b"])
+
+                if  (type(V[1]) == int or type(V[1]) == float):
+                    
+                    p_x = V[0][0]
+                    p_y = V[0][1]
+
+                    r = V[1]
+                    theta_str = V[2]
+                    theta = math.radians(float(theta_str[:]))
+
+                    coor1 = round(r*math.cos(theta),3)
+                    coor2 = round(r*math.sin(theta),3)
+
+                    color = randomRgbaColor()
+                    x.append(coor1 + p_x)
+                    x.append(p_x)
+                    y.append(coor2 + p_y)
+                    y.append(p_y)
+                    #fig.add_trace(go.Scatter(x=[V[0]],y=[V[1]],mode='markers',marker=dict(color= color,size=7),showlegend=True,name="vector "+ str(args.index(V)+1)))
+                    fig.add_trace(go.Scatter(x=[p_x,coor1+p_x], y=[p_y,coor2+p_y],mode='lines',marker=dict(color= color,size=8),showlegend=True,name="vector "+ str(args.index(V)+1)))
+                    fig.add_annotation(
+                    x=coor1 + p_x,  # Coordenada en x cabeza
+                    y=coor2 + p_y,  # Coordenada en y cabeza
+                    ax=p_x,  # Coordenada en x de la cola
+                    ay=p_y,  # Coordenada en x de la cola
+                    xref='x',
+                    yref='y',
+                    axref='x',
+                    ayref='y',
+                    showarrow=True,
+                    arrowhead=2,
+                    arrowsize=1.5,
+                    arrowwidth=2.3,
+                    arrowcolor = color)
+
                 if type(V[1]) == list:
 
+                    # plotvector2D([(x0,y0),[x]])
                     if len(V[1])==1:
                         
                         color = randomRgbaColor()
@@ -130,43 +179,10 @@ def plotvectors2D(*args):
                         arrowsize=1.5,
                         arrowwidth=2.3,
                         arrowcolor = color)
-
-                    if type(V[1][1])==str:
-                        
-                        p_x = V[0][0]
-                        p_y = V[0][1]
-
-                        r = V[1][0]
-                        theta_str = V[1][1]
-                        theta = math.radians(float(theta_str[:]))
-
-                        coor1 = round(r*math.cos(theta),3)
-                        coor2 = round(r*math.sin(theta),3)
-
-                        color = randomRgbaColor()
-                        x.append(coor1 + p_x)
-                        x.append(p_x)
-                        y.append(coor2 + p_y)
-                        y.append(p_y)
-                        #fig.add_trace(go.Scatter(x=[V[0]],y=[V[1]],mode='markers',marker=dict(color= color,size=7),showlegend=True,name="vector "+ str(args.index(V)+1)))
-                        fig.add_trace(go.Scatter(x=[p_x,coor1+p_x], y=[p_y,coor2+p_y],mode='lines',marker=dict(color= color,size=8),showlegend=True,name="vector "+ str(args.index(V)+1)))
-                        fig.add_annotation(
-                        x=coor1 + p_x,  # Coordenada en x cabeza
-                        y=coor2 + p_y,  # Coordenada en y cabeza
-                        ax=p_x,  # Coordenada en x de la cola
-                        ay=p_y,  # Coordenada en x de la cola
-                        xref='x',
-                        yref='y',
-                        axref='x',
-                        ayref='y',
-                        showarrow=True,
-                        arrowhead=2,
-                        arrowsize=1.5,
-                        arrowwidth=2.3,
-                        arrowcolor = color)
-
+                
                     else:
 
+                        # plotvector2D([(x0,y0),[x,y]])
                         color = randomRgbaColor()
                         x.append(V[0][0])
                         x.append(V[1][0]+V[0][0])
@@ -189,7 +205,7 @@ def plotvectors2D(*args):
                         arrowwidth=2.3,
                         arrowcolor = color)
 
-                    
+                # plotvector2D([(x1,y1),(x2,y2)])
                 if type(V[1]) == tuple:
                     
                     color = randomRgbaColor()
@@ -214,8 +230,9 @@ def plotvectors2D(*args):
                     arrowwidth=2.3,
                     arrowcolor = color)
                     
-                if type(V[1]) != list and type(V[1]) != tuple:
+                if type(V[1]) != list and type(V[1]) != tuple and type(V[1]) != int and type(V[1]) != float:
 
+                    # plotvector2D([(x0,y0),A]) A = Matrix([x])
                     if len(V[1])== 1:
                         
                         color = randomRgbaColor()
@@ -243,7 +260,7 @@ def plotvectors2D(*args):
                         arrowcolor = color)
 
                     else:
-                        
+                        # plotvector2D([(x0,y0),A]) A = Matrix([x,y])
                         color = randomRgbaColor()
                         a = np.array(V[1]).astype(np.float64).tolist()[0][0]
                         b = np.array(V[1]).astype(np.float64).tolist()[1][0]
@@ -270,7 +287,8 @@ def plotvectors2D(*args):
 
         
         if type(V) != list:
-
+            
+            # plotvector2D(A) A = Matrix([x])
             if len(V) == 1:
                 color = randomRgbaColor()
                 a = np.array(V).astype(np.float64).tolist()[0][0]
@@ -295,7 +313,7 @@ def plotvectors2D(*args):
                 arrowcolor = color)
 
             else:
-
+                # plotvector2D(A) A = Matrix([x,y])
                 color = randomRgbaColor()
                 a = np.array(V).astype(np.float64).tolist()[0][0]
                 b = np.array(V).astype(np.float64).tolist()[1][0]
@@ -334,8 +352,12 @@ def plotvectors2D(*args):
     fig.show()
 
 def plotvectors3D(*args):
-    '''Función elaborada en el módulo Plotly y NumPy para representar graficamente multiples vectores libres y fijos en el espacio,
-    ademas de vectores equipolentes que inicien en un punto dado, acepta como argumento vectores de la librería SymPy'''
+    
+    '''Función elaborada con el módulo Plotly y Numpy, permite visualizar multiples vectores en el espacio tridimensional, que pueden tener
+     un punto inicial y un punto final dado, estar anclados en el origen del espacio, o vectores equipolentes a otro que inicie en un 
+     punto dado (traslación de vectores), y vectores desde una magnitud y un vector director unitario dado, acepta como argumentos 
+     vectores columna tridimensionales definidos en la librería SymPy.'''
+   
     data = []
     x = [0]
     y = [0]
@@ -882,3 +904,4 @@ def plotvectors3D(*args):
 
     plot(fig,image_height=800,image_width=800)
     fig.show()
+
